@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 __author__ = 'Carlos Damázio'
-__email__ = 'kaduardobsb95@gmail.com'
-__version__ = '1.1.0'
+__email__ = 'carlos.damazio@damazio.dev'
+__version__ = '1.2.0'
 
 
 from .python_aisweb import AISWEB
